@@ -13,6 +13,7 @@ from notecoin.okex.websocket.connect import PublicConnect
 class WebsocketService(APIRouter):
     def __init__(self, connect: BaseConnect = None, prefix='/websocket', *args, **kwargs):
         self.connect = connect or PublicConnect(channels=[PublicChannel.public_tickers().to_json()])
+        self.connect.add_handle(PublicTickers())
         super(WebsocketService, self).__init__(prefix=prefix, *args, **kwargs)
         add_api_routes(self)
         self.connect.run()
@@ -33,12 +34,13 @@ class WebsocketService(APIRouter):
             session.merge(OkexWebsocketChannels(**param))
         create_all()
         session.commit()
-        return {"success": len(details)}
+        return {"update_db": len(details)}
 
     @api_route('/update/channel', description="get value")
     def update_channels(self):
+
         try:
-            self.update_channels_db()
+            res = self.update_channels_db()
 
             new_channels = session.query(OkexWebsocketChannels).all()
             new_channels = [eval(channel.channel_json) for channel in new_channels]
@@ -51,6 +53,8 @@ class WebsocketService(APIRouter):
                     logging.info(f"old:{old_channels_str},new:{new_channels_str}")
                     self.connect.channels = new_channels
                     self.connect.subscribe_restart()
-            return {"update": "success"}
+            res["update"] = ["success"]
         except Exception as e:
-            return {"update": "fails", "error": str(e)}
+            res["update"] = ["failed"]
+            res["error"] = str(e)
+        return res
