@@ -64,9 +64,6 @@ class BaseConnect:
 
     def ping(self):
         self.ws.send('ping')
-        res = self.ws.recv()
-        logging.info(res)
-        assert res == 'pong'
 
     def subscribe_restart(self):
         self.subscribe_stop()
@@ -90,8 +87,6 @@ class BaseConnect:
 
         self.ws.send(login_str)
         logging.info(f"send: {login_str}")
-        res = self.ws.recv()
-        logging.info(f"recv: {res}")
         time.sleep(1)
 
     def subscribe_stop(self):
@@ -100,8 +95,6 @@ class BaseConnect:
         sub_str = json.dumps(sub_param)
         self.ws.send(sub_str)
         logging.info(f"send: {sub_str}")
-        res = self.ws.recv()
-        logging.info(f"recv: {res}")
 
 
 class PublicConnect(BaseConnect):
